@@ -1,26 +1,54 @@
-import shutil
 import json
-import time
 import random
-import requests
+import shutil
+import time
 from pathlib import Path
-from typing import List
-from uuid import uuid4
-from PIL import Image
+from typing import Dict, List
 from urllib.parse import urlparse
+from uuid import uuid4
+
+import requests
 
 from instagrapi import config
-from instagrapi.extractors import extract_media_v1
 from instagrapi.exceptions import (
-    PhotoNotUpload, PhotoConfigureError, PhotoConfigureStoryError
+    PhotoConfigureError,
+    PhotoConfigureStoryError,
+    PhotoNotUpload,
 )
-from instagrapi.types import Usertag, Location, StoryMention, StoryLink, Media
+
+from instagrapi.extractors import extract_media_v1
+from instagrapi.types import Location, Media, Story, StoryLink, StoryMention, Usertag
+
 from instagrapi.utils import dumps
 
+try:
+    from PIL import Image
+except ImportError:
+    raise Exception("You don't have PIL installed. Please install PIL or Pillow>=7.2.0")
+
 
 class DownloadPhotoMixin:
+    """
+    Helpers for downloading photo
+    """
 
     def photo_download(self, media_pk: int, folder: Path = "") -> Path:
+        """
+        Download photo using media pk
+
+        Parameters
+        ----------
+        media_pk: int
+            Unique Media ID
+        folder: Path, optional
+            Directory in which you want to download the album, default is "" and will download the files to working
+                directory
+
+        Returns
+        -------
+        Path
+            Path for the file downloaded
+        """
         media = self.media_info(media_pk)
         assert media.media_type == 1, "Must been photo"
         filename = "{username}_{media_pk}".format(
@@ -29,6 +57,24 @@ class DownloadPhotoMixin:
         return self.photo_download_by_url(media.thumbnail_url, filename, folder)
 
     def photo_download_by_url(self, url: str, filename: str = "", folder: Path = "") -> Path:
+        """
+        Download photo using media pk
+
+        Parameters
+        ----------
+        url: str
+            URL for a media
+        filename: str, optional
+            Filename for the media
+        folder: Path, optional
+            Directory in which you want to download the album, default is "" and will download the files to working
+                directory
+
+        Returns
+        -------
+        Path
+            Path for the file downloaded
+        """
         fname = urlparse(url).path.rsplit('/', 1)[1]
         filename = "%s.%s" % (filename, fname.rsplit('.', 1)[
                               1]) if filename else fname
@@ -42,6 +88,9 @@ class DownloadPhotoMixin:
 
 
 class UploadPhotoMixin:
+    """
+    Helpers for downloading photo
+    """
 
     def photo_rupload(
         self,
@@ -49,13 +98,21 @@ class UploadPhotoMixin:
         upload_id: str = "",
         to_album: bool = False
     ) -> tuple:
-        """Upload photo to Instagram
+        """
+        Upload photo to Instagram
 
-        :param path:         Path to photo file
-        :param upload_id:    Unique upload_id (String). When None, then generate
-                             automatically. Example from video.video_configure
+        Parameters
+        ----------
+        path: Path
+            Path to the media
+        upload_id: str, optional
+            Unique upload_id (String). When None, then generate automatically. Example from video.video_configure
+        to_album: bool, optional
 
-        :return: Tuple (upload_id, width, height)
+        Returns
+        -------
+        tuple
+            (Upload ID for the media, width, height)
         """
         assert isinstance(path, Path), f"Path must been Path, now {path} ({type(path)})"
         upload_id = upload_id or str(int(time.time() * 1000))
@@ -117,20 +174,34 @@ class UploadPhotoMixin:
         configure_handler=None,
         configure_exception=None
     ) -> Media:
-        """Upload photo and configure to feed
+        """
+        Upload photo and configure to feed
 
-        :param path:                Path to photo file
-        :param caption:             Media description (String)
-        :param upload_id:           Unique upload_id (String). When None, then generate
-                                        automatically. Example from video.video_configure
-        :param usertags:            Mentioned users (List)
-        :param location:            Location
-        :param links:               URLs for Swipe Up (List of dicts)
-        :param configure_timeout:   Timeout between attempt to configure media (set caption, etc)
-        :param configure_handler:   Configure handler method
-        :param configure_exception: Configure exception class
+        Parameters
+        ----------
+        path: Path
+            Path to the media
+        caption: str
+            Media caption
+        upload_id: str, optional
+            Unique upload_id (String). When None, then generate automatically. Example from video.video_configure
+        usertags: List[Usertag], optional
+            List of users to be tagged on this upload, default is empty list.
+        location: Location, optional
+            Location tag for this upload, default is None
+        links: List[StoryLink]
+            URLs for Swipe Up
+        configure_timeout: int
+            Timeout between attempt to configure media (set caption, etc), default is 3
+        configure_handler
+            Configure handler method, default is None
+        configure_exception
+            Configure exception class, default is None
 
-        :return: Media
+        Returns
+        -------
+        Media
+            An object of Media class
         """
         path = Path(path)
         upload_id, width, height = self.photo_rupload(path, upload_id)
@@ -153,18 +224,31 @@ class UploadPhotoMixin:
         usertags: List[Usertag] = [],
         location: Location = None,
         links: List[StoryLink] = []
-    ) -> dict:
-        """Post Configure Photo (send caption to Instagram)
+    ) -> Dict:
+        """
+        Post Configure Photo (send caption to Instagram)
 
-        :param upload_id:  Unique upload_id (String)
-        :param width:      Width in px (Integer)
-        :param height:     Height in px (Integer)
-        :param caption:    Media description (String)
-        :param usertags:   Mentioned users (List)
-        :param location:   Location
-        :param links:      URLs for Swipe Up (List of dicts)
+        Parameters
+        ----------
+        upload_id: str
+            Unique upload_id
+        width: int
+            Width of the video in pixels
+        height: int
+            Height of the video in pixels
+        caption: str
+            Media caption
+        usertags: List[Usertag], optional
+            List of users to be tagged on this upload, default is empty list.
+        location: Location, optional
+            Location tag for this upload, default is None
+        links: List[StoryLink]
+            URLs for Swipe Up
 
-        :return: Media (Dict)
+        Returns
+        -------
+        Dict
+            A dictionary of response from the call
         """
         usertags = [
             {"user_id": tag.user.pk, "position": [tag.x, tag.y]}
@@ -198,26 +282,38 @@ class UploadPhotoMixin:
         mentions: List[StoryMention] = [],
         links: List[StoryLink] = [],
         configure_timeout: int = 3
-    ) -> Media:
-        """Upload photo and configure to story
-
-        :param path:                Path to photo file
-        :param caption:             Media description (String)
-        :param upload_id:           Unique upload_id (String). When None, then generate
-                                        automatically. Example from video.video_configure
-        :param mentions:            Mentioned users (List)
-        :param links:               URLs for Swipe Up (List of dicts)
-        :param configure_timeout:   Timeout between at<tempt to configure media (set caption, etc)
-
-        :return: Media
+    ) -> Story:
         """
-        return self.photo_upload(
+        Upload photo as a story and configure it
+
+        Parameters
+        ----------
+        path: Path
+            Path to the media
+        caption: str
+            Media caption
+        upload_id: str, optional
+            Unique upload_id (String). When None, then generate automatically. Example from video.video_configure
+        mentions: List[StoryMention], optional
+            List of mentions to be tagged on this upload, default is empty list.
+        links: List[StoryLink]
+            URLs for Swipe Up
+        configure_timeout: int
+            Timeout between attempt to configure media (set caption, etc), default is 3
+
+        Returns
+        -------
+        Story
+            An object of Media class
+        """
+        media = self.photo_upload(
             path, caption, upload_id, mentions,
             links=links,
             configure_timeout=configure_timeout,
             configure_handler=self.photo_configure_to_story,
             configure_exception=PhotoConfigureStoryError
         )
+        return Story(links=links, mentions=mentions, **media.dict())
 
     def photo_configure_to_story(
         self,
@@ -228,18 +324,31 @@ class UploadPhotoMixin:
         mentions: List[StoryMention] = [],
         location: Location = None,
         links: List[StoryLink] = []
-    ) -> dict:
-        """Story Configure for Photo
+    ) -> Dict:
+        """
+        Post configure photo
 
-        :param upload_id:  Unique upload_id (String)
-        :param width:      Width in px (Integer)
-        :param height:     Height in px (Integer)
-        :param caption:    Media description (String)
-        :param usertags:   Mentioned users (List)
-        :param location:   Temporary unused
-        :param links:      URLs for Swipe Up (List of dicts)
+        Parameters
+        ----------
+        upload_id: str
+            Unique upload_id
+        width: int
+            Width of the video in pixels
+        height: int
+            Height of the video in pixels
+        caption: str
+            Media caption
+        mentions: List[StoryMention], optional
+            List of mentions to be tagged on this upload, default is empty list.
+        location: Location, optional
+            Location tag for this upload, default is None
+        links: List[StoryLink]
+            URLs for Swipe Up
 
-        :return: Media (Dict)
+        Returns
+        -------
+        Dict
+            A dictionary of response from the call
         """
         timestamp = int(time.time())
         data = {
